@@ -29,10 +29,11 @@ if (is.finite(check.for.jump[1])) # warning and different plot
 	from1to3 <- check.for.jump[3] - check.for.jump[2]
 	if (first.space > (from1to3 * 1e10)) {
 		warning(paste("These parameter values give a pathological density.  \n",
-		"The theoretical minimum: F^{-1}(0)=",signif(check.for.jump[1],4),"\n is much less than F^{-1}("
-		,signif(nearzero[2],4),")=",signif(check.for.jump[2],4),"The density is undefined between these points"))
+		"The theoretical minimum: F^{-1}(0)= ",signif(check.for.jump[1],4),"\n is much less than F^{-1}("
+		,signif(nearzero[2],4),")= ",signif(check.for.jump[2],4),".\n","The density is undefined between these points",sep=""))
 		dots.required <- TRUE
 		dots.start <- TRUE
+		dots.end <- FALSE
 		}
 	}
 if (is.finite(check.for.jump2[1])) # warning and different plot
@@ -41,10 +42,11 @@ if (is.finite(check.for.jump2[1])) # warning and different plot
 	from1to3 <- check.for.jump2[2] - check.for.jump2[3]
 	if (last.space > (from1to3 * 1e10)) {
 		warning(paste("These parameter values give a pathological density.  \n",
-		"The theoretical maximum: F^{-1}(1)=",signif(check.for.jump2[1],4),
-		"\n is much more than F^{-1}(1-",signif(nearzero[2],4),")=",signif(check.for.jump2[2],4),".\n","The density is undefined between these points"))
+		"The theoretical maximum: F^{-1}(1)= ",signif(check.for.jump2[1],4),
+		"\n is much more than F^{-1}(1-", signif(nearzero[2],4),")= ",signif(check.for.jump2[2],4),".\n","The density is undefined between these points",sep=""))
 		dots.required <- TRUE
 		dots.end <- TRUE
+		if (!exists("dots.start")) { dots.start <- FALSE }
 		}
 	}
 if(truncate > 0) { 
